==> hopach_2.12.0.zip: hopach/doc/hopach.R <==
###################################################
### chunk number 1: golub
###################################################
#line 69 "hopach.Rnw"
library(hopach)
data(golub)


###################################################
### chunk number 2: geneSelection
###################################################
#line 76 "hopach.Rnw"
vars<-apply(golub,1,var)
subset<-vars>quantile(vars,(nrow(golub)-200)/nrow(golub))
golub.subset<-golub[subset,]
dim(golub.subset)
gnames.subset<-golub.gnames[subset,]


###################################################
### chunk number 3: distance
###################################################
#line 86 "hopach.Rnw"
gene.dist<-distancematrix(golub.subset,"cosangle")
dim(gene.dist)


###################################################
### chunk number 4: hopachGene
###################################################
#line 93 "hopach.Rnw"
gene.hobj<-hopach(golub.subset,dmat=gene.dist)
gene.hobj$clust$k  
table(gene.hobj$clust$labels) 
gene.hobj$clust$sizes 


###################################################
### chunk number 5: dplot eval=FALSE
###################################################
## #line 102 "hopach.Rnw"
## dplot(gene.dist,gene.hobj,ord="final",main="Golub AML/ALL Data (1999): Gene Distance Matrix",showclusters=FALSE)  


###################################################
### chunk number 6: bootstrap
###################################################
#line 111 "hopach.Rnw"
bobj<-boothopach(golub.subset,gene.hobj,B=100)


###################################################
### chunk number 7: bootplot eval=FALSE
###################################################
## #line 117 "hopach.Rnw"
## bootplot(bobj,gene.hobj,ord="bootp",main="Golub AML/ALL Data (1999)",showclusters=FALSE)


###################################################
### chunk number 8: classes eval=FALSE
###################################################
## #line 126 "hopach.Rnw"
## table(golub.cl)


###################################################
### chunk number 9: hopachArray
###################################################
#line 132 "hopach.Rnw"
array.hobj<-hopach(t(golub.subset),d="euclid")
array.hobj$clust$k


###################################################
### chunk number 10: output eval=FALSE
###################################################
## #line 144 "hopach.Rnw"
## makeoutput(golub.subset,gene.hobj,bobj,file="Golub.out",gene.names=gnames.subset[,3])


###################################################
### chunk number 11: fuzzy eval=FALSE
###################################################
## #line 152 "hopach.Rnw"
## boot2fuzzy(golub.subset,bobj,gene.hobj,array.hobj,file="GolubFuzzy",gene.names=gnames.subset[,3]) 


###################################################
### chunk number 12: hierarchical eval=FALSE
###################################################
## #line 162 "hopach.Rnw"
## hopach2tree(golub.subset,file="GolubTree",hopach.genes=gene.hobj,hopach.arrays=NULL,dist.genes=gene.dist,gene.names=gnames.subset[,3])

==> hopach_2.68.0.zip: hopach/doc/hopach.R <==
### R code from vignette source 'hopach.Rnw'

###################################################
### code chunk number 1: golub
###################################################
library(hopach)
data(golub)


###################################################
### code chunk number 2: geneSelection
###################################################
vars<-apply(golub,1,var)
subset<-vars>quantile(vars,(nrow(golub)-200)/nrow(golub))
golub.subset<-golub[subset,]
dim(golub.subset)
gnames.subset<-golub.gnames[subset,]


###################################################
### code chunk number 3: distance
###################################################
gene.dist<-distancematrix(golub.subset,"cosangle")
dim(gene.dist)


###################################################
### code chunk number 4: hopachGene
###################################################
gene.hobj<-hopach(golub.subset,dmat=gene.dist)
gene.hobj$clust$k  
table(gene.hobj$clust$labels) 
gene.hobj$clust$sizes 


###################################################
### code chunk number 5: dplot (eval = FALSE)
###################################################
## dplot(gene.dist,gene.hobj,ord="final",main="Golub AML/ALL Data (1999): Gene Distance Matrix",showclusters=FALSE)  


###################################################
### code chunk number 6: bootstrap
###################################################
bobj<-boothopach(golub.subset,gene.hobj,B=100)


###################################################
### code chunk number 7: bootplot (eval = FALSE)
###################################################
## bootplot(bobj,gene.hobj,ord="bootp",main="Golub AML/ALL Data (1999)",showclusters=FALSE)


###################################################
### code chunk number 8: classes (eval = FALSE)
###################################################
## table(golub.cl)


###################################################
### code chunk number 9: hopachArray
###################################################
array.hobj<-hopach(t(golub.subset),d="euclid")
array.hobj$clust$k


###################################################
### code chunk number 10: output (eval = FALSE)
###################################################
## makeoutput(golub.subset,gene.hobj,bobj,file="Golub.out",gene.names=gnames.subset[,3])


###################################################
### code chunk number 11: fuzzy (eval = FALSE)
###################################################
## boot2fuzzy(golub.subset,bobj,gene.hobj,array.hobj,file="GolubFuzzy",gene.names=gnames.subset[,3]) 


###################################################
### code chunk number 12: hierarchical (eval = FALSE)
###################################################
## hopach2tree(golub.subset,file="GolubTree",hopach.genes=gene.hobj,hopach.arrays=NULL,dist.genes=gene.dist,gene.names=gnames.subset[,3])
